@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: UploadItem.h 479 2005-07-23 12:53:27Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -79,15 +79,15 @@ public:
     UploadItem(apr_pool_t *pool, const char *file_path, header *header);
     explicit UploadItem(apr_pool_t *pool);
     header *set_data(const char *file_path, header *header);
-    header *get_header();
-    const char *get_file_path();
-    const char *get_file_name();
-    const char *get_comment();
-    const char *get_remove_pass();
-    const char *get_download_pass();
-    const char *get_file_size();
-    const char *get_file_mime();
-    const char *get_time();
+    header *get_header() const;
+    const char *get_file_path() const;
+    const char *get_file_name() const;
+    const char *get_comment() const;
+    const char *get_remove_pass() const;
+    const char *get_download_pass() const;
+    const char *get_file_size() const;
+    const char *get_file_mime() const;
+    const char *get_time() const;
 #ifdef DEBUG
     static void dump_header(header *header);
 #endif
