@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 473 2005-07-22 13:50:06Z svn $
+ * $Id: TemplateLexer.cpp 483 2005-07-23 20:52:16Z svn $
  *****************************************************************************/
 
 #include "TemplateLexer.h"
@@ -331,51 +331,17 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
 
         h->input++;
         break;
-
-    case GREATER_THAN_CHAR:
-        token->type = GREATER_THAN;
-        h->input++;
-        break;
-    case LESS_THAN_CHAR:
-        token->type = LESS_THAN;
-        h->input++;
-        break;
-    case BRACE_LEFT_CHAR:
-        token->type = BRACE_LEFT;
-        h->input++;
-        break;
-    case BRACE_RIGHT_CHAR:
-        token->type = BRACE_RIGHT;
-        h->input++;
-        break;
-    case PAREN_LEFT_CHAR:
-        token->type = PAREN_LEFT;
-        h->input++;
-        break;
-    case PAREN_RIGHT_CHAR:
-        token->type = PAREN_RIGHT;
-        h->input++;
-        break;
-    case BRACKET_LEFT_CHAR:
-        token->type = BRACKET_LEFT;
-        h->input++;
-        break;
-    case BRACKET_RIGHT_CHAR:
-        token->type = BRACKET_RIGHT;
-        h->input++;
-        break;
-    case DOT_CHAR:
-        token->type = DOT;
-        h->input++;
-        break;
-    case COMMA_CHAR:
-        token->type = COMMA;
-        h->input++;
-        break;
-    case DELIMITER_CHAR:
-        token->type = DELIMITER;
-        h->input++;
-        break;
+    case GREATER_THAN_CHAR:  token->type = GREATER_THAN;  h->input++; break;
+    case LESS_THAN_CHAR:     token->type = LESS_THAN;     h->input++; break;
+    case BRACE_LEFT_CHAR:    token->type = BRACE_LEFT;    h->input++; break;
+    case BRACE_RIGHT_CHAR:   token->type = BRACE_RIGHT;   h->input++; break;
+    case PAREN_LEFT_CHAR:    token->type = PAREN_LEFT;    h->input++; break;
+    case PAREN_RIGHT_CHAR:   token->type = PAREN_RIGHT;   h->input++; break;
+    case BRACKET_LEFT_CHAR:  token->type = BRACKET_LEFT;  h->input++; break;
+    case BRACKET_RIGHT_CHAR: token->type = BRACKET_RIGHT; h->input++; break;
+    case DOT_CHAR:           token->type = DOT;           h->input++; break;
+    case COMMA_CHAR:         token->type = COMMA;         h->input++; break;
+    case DELIMITER_CHAR:     token->type = DELIMITER;     h->input++; break;
     default:
         if (input_match(CODE_END_STR)) {
             h->input += strlen(CODE_END_STR);
