@@ -24,10 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 473 2005-07-22 13:50:06Z svn $
+ * $Id: UploaderConfig.cpp 480 2005-07-23 14:46:26Z svn $
  *****************************************************************************/
 
 #include "UploaderConfig.h"
+#include "Misc.h"
 
 #ifdef WIN32
 #include <Windows.h>
@@ -61,6 +62,7 @@ static apr_status_t finalize_config(void *data);
 static apr_status_t finalize_rwlock(void *data);
 #endif
 
+
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
@@ -106,7 +108,7 @@ UploaderConfig::~UploaderConfig()
 
 void UploaderConfig::init(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
-    if (is_init) {
+    if (LIKELY(is_init)) {
         return update_list(pool, tmp_pool);
     }
 
@@ -158,7 +160,7 @@ void UploaderConfig::finalize()
 
 UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *pool)
 {
-    if (get_mtime(pool, view_tmpl_path) > view_tmpl->mtime) {
+    if (UNLIKELY(get_mtime(pool, view_tmpl_path) > view_tmpl->mtime)) {
         load_template(pool, &view_tmpl_pool, view_tmpl_path, view_tmpl);
     }
 
@@ -167,7 +169,7 @@ UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *poo
 
 UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t *pool)
 {
-    if (get_mtime(pool, download_tmpl_path) > download_tmpl->mtime) {
+    if (UNLIKELY(get_mtime(pool, download_tmpl_path) > download_tmpl->mtime)) {
         load_template(pool, &download_tmpl_pool, download_tmpl_path, download_tmpl);
     }
 
@@ -176,7 +178,7 @@ UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t
 
 UploaderConfig::page_template *UploaderConfig::get_thumb_template(apr_pool_t *pool)
 {
-    if (get_mtime(pool, thumb_tmpl_path) > thumb_tmpl->mtime) {
+    if (UNLIKELY(get_mtime(pool, thumb_tmpl_path) > thumb_tmpl->mtime)) {
         load_template(pool, &thumb_tmpl_pool, thumb_tmpl_path, thumb_tmpl);
     }
 
@@ -185,7 +187,7 @@ UploaderConfig::page_template *UploaderConfig::get_thumb_template(apr_pool_t *po
 
 UploaderConfig::page_template *UploaderConfig::get_error_template(apr_pool_t *pool)
 {
-    if (get_mtime(pool, error_tmpl_path) > error_tmpl->mtime) {
+    if (UNLIKELY(get_mtime(pool, error_tmpl_path) > error_tmpl->mtime)) {
         load_template(pool, &error_tmpl_pool, error_tmpl_path, error_tmpl);
     }
 
@@ -377,7 +379,7 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *file_path)
 {
     apr_finfo_t info;
 
-    if (apr_stat(&info, file_path, APR_FINFO_MTIME, pool) != APR_SUCCESS) {
+    if (UNLIKELY(apr_stat(&info, file_path, APR_FINFO_MTIME, pool) != APR_SUCCESS)) {
         throw "եޤϥǥ쥯ȥιǤޤǤ";
     }
 
